@@ -49,6 +49,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
    	if (rotate=="varimax" | rotate=="quartimax") { 
    			rotated <- do.call(rotate,list(loadings))
    			loadings <- rotated$loadings
+   			 colnames(loadings) <- paste("RC",1:nfactors,sep='')
    			 Phi <- NULL} else { 
      			if ((rotate=="promax")|(rotate=="Promax")) {pro <- Promax(loadings)
      			                loadings <- pro$loadings
@@ -56,12 +57,14 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
      			if (rotate == "cluster") {loadings <- varimax(loadings)$loadings           			
 								pro <- target.rot(loadings)
      			              	loadings <- pro$loadings
+     			              	colnames(loadings) <- paste("TC",1:nfactors,sep='')
      			                Phi <- pro$Phi} else {
      			                     
      			if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax") {
      				if (!require(GPArotation)) {warning("I am sorry, to do these rotations requires the GPArotation package to be installed")
      				Phi <- NULL} else { ob  <- do.call(rotate,list(loadings) )
      				loadings <- ob$loadings
+     				colnames(loadings) <- paste("TC",1:nfactors,sep='')
      				 Phi <- ob$Phi}
      		                             }
      	               }}}
@@ -73,7 +76,16 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
     ev.order <- order(ev.rotated,decreasing=TRUE)
     loadings <- loadings[,ev.order]}
     if(!is.null(Phi)) {Phi <- Phi[ev.order,ev.order] } #January 20, 2009 but, then, we also need to change the order of the rotation matrix!
+    signed <- sign(colSums(loadings))
+    c.names <- colnames(loadings)
+    signed[signed==0] <- 1
+    loadings <- loadings %*% diag(signed)  #flips factors to be in positive direction but loses the colnames
+     colnames(loadings) <- c.names
+    if(!is.null(Phi)) {Phi <- diag(signed) %*% Phi %*% diag(signed) 
+                     colnames(Phi) <- rownames(Phi) <- c.names} 
    
+    
+    
      class(loadings) <- "loadings"
      
     result$n.obs <- n.obs
